@@ -7,7 +7,7 @@
  * published by the Free Software Foundation; either version 2 of
  * the License or (at your option) version 3 or any later version
  * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy 
+ * by the membership of KDE e.V.), which shall act as a proxy
  * defined in Section 14 of version 3 of the license.
  *
  * This program is distributed in the hope that it will be useful,
@@ -23,6 +23,8 @@
 
 #include <QHash>
 
+#include <KDebug>
+#include <KGlobal>
 #include <KUrl>
 #include <KLocale>
 #include <Phonon/MediaController>
@@ -36,11 +38,9 @@
 #include <xine.h>
 #endif
 
-#include "debug.h"
-#include "mxcl.library.h"
 #include "videoWindow.h"
 
-namespace Codeine
+namespace Dragon
 {
 
     const char* TheStream::CHANNEL_PROPERTY = "channel";
@@ -59,14 +59,14 @@ namespace Codeine
                 Solid::StorageVolume* disc = deviceList.first().as<Solid::StorageVolume>();
                 if( disc )
                 {
-                    QString discLabel = QString("disc:%1,%2").arg( disc->uuid(), disc->label() );
+                    QString discLabel = QString::fromLatin1("disc:%1,%2").arg( disc->uuid(), disc->label() );
                     return KConfigGroup( KGlobal::config(), discLabel );
                 }
                 else
-                    debug() << "profile: doesn't convert into Solid::StorageVolume";
+                    kDebug() << "profile: doesn't convert into Solid::StorageVolume";
             }
             else
-                debug() << "profile: empty device list";
+                kDebug() << "profile: empty device list";
         }
         //if not a disc, or Solid fails
         return KConfigGroup( KGlobal::config(), url().prettyUrl() );
@@ -74,7 +74,7 @@ namespace Codeine
 
     KUrl
     TheStream::url()
-    { 
+    {
         return videoWindow()->m_media->currentSource().url();
     }
 
@@ -98,7 +98,7 @@ namespace Codeine
           return false;
         if(videoWindow()->m_media->currentSource().type() == Phonon::MediaSource::Empty)
           return false;
-        //otherwise 
+        //otherwise
         return true;
     }
 
@@ -123,7 +123,7 @@ namespace Codeine
     void
     TheStream::addRatio( int aspectEnum, QAction* ratioAction )
     {
-        s_aspectRatioActions[aspectEnum] = ratioAction; 
+        s_aspectRatioActions[aspectEnum] = ratioAction;
     }
 
     int
@@ -150,13 +150,13 @@ namespace Codeine
     {
         const KUrl& url      = videoWindow()->m_media->currentSource().url();
         QString artist, title;
-        
-        QStringList artists = videoWindow()->m_media->metaData("ARTIST");
+
+        QStringList artists = videoWindow()->m_media->metaData(QLatin1String( "ARTIST" ));
         if (!artists.isEmpty()) {
             artist = artists.first();
         }
-        
-        QStringList titles = videoWindow()->m_media->metaData("TITLE");
+
+        QStringList titles = videoWindow()->m_media->metaData(QLatin1String( "TITLE" ));
         if (!titles.isEmpty()) {
             title  = titles.first();
         }
@@ -164,26 +164,50 @@ namespace Codeine
         if (hasVideo() && !title.isEmpty())
             return title;
         else if (!title.isEmpty() && !artist.isEmpty())
-            return artist + " - " + title;
-        else if (url.protocol() != "http" && !url.fileName().isEmpty()) 
+            return artist + QLatin1String( " - " ) + title;
+        else if (url.protocol() != QLatin1String( "http" ) && !url.fileName().isEmpty())
         {
             const QString n = url.fileName();
             //toLatin1 sense fromPercentEncoding takes a QByteArray
             //I'm not sure about this whole method though, should double check that titles make sense
             //using QString::toLatin1() will display "????" in titlelabel. Should be QString::toUtf8().   patched by nihui, Jul.6th, 2008
-            return QUrl::fromPercentEncoding( n.left( n.lastIndexOf( '.' ) ).replace( '_', ' ' ).toUtf8() ); //krazy:exclude-qclasses
+            return QUrl::fromPercentEncoding( n.left( n.lastIndexOf( QLatin1Char( '.' ) ) ).replace( QLatin1Char( '_' ), QLatin1Char( ' ' ) ).toUtf8() ); //krazy:exclude-qclasses
 
         }
         else
             return url.prettyUrl();
     }
 
+    QString
+    TheStream::fullTitle()
+    {/*
+      QString artist,album,title;
+      QStringList artists = m_mediaObject->metaData(Phonon::ArtistMetaData);
+      QStringList albums = m_mediaObject->metaData(Phonon::AlbumMetaData);
+      QStringList titles = m_mediaObject->metaData(Phonon::TitleMetaData)
+      title = (title ? titles.join( QLatin1String( " ") : "" ) );
+      album = (albums ? albums.join( QLatin1String( " "): "" ) );
+      artist = (artists ? artists.join( QLatin1String( " "): "" ) );
+
+      return title + "\n" + album + "\n" + artist;*/
+      return QString();
+    }
+
     bool
     TheStream::hasProfile()
-    { 
+    {
         return KGlobal::config()->hasGroup( url().prettyUrl() );
     }
 
+    QString
+    TheStream::metaData(Phonon::MetaData key)
+    {
+        QStringList values = videoWindow()->m_media->metaData(key);
+        kDebug() << values;
+        return (values.isEmpty()) ? QString() : values.join(QString(QLatin1Char( ' ' )));
+    }
+
+
 /*
     static inline QString
     entryHelper( const QString &plate, const QString &s1, const QString &s2 )
@@ -210,10 +234,10 @@ namespace Codeine
 //         #define meta( x ) xine_get_meta_info( VideoWindow::s_instance->m_stream, x )
 //         #define info( x, y ) x.arg( xine_get_stream_info( VideoWindow::s_instance->m_stream, y ) )
 //         #define simple( x ) QString::number( xine_get_stream_info( VideoWindow::s_instance->m_stream, x ) )
-// 
+//
 //         const QString plate = "<p><b>%1</b>: %2</p>";
 //         QString s;
-// 
+//
 //         s += sectionHelper( i18n("Metadata"),
 //             QStringList()
 //                 << entryHelper( plate, i18n("Title"), meta( XINE_META_INFO_TITLE ) )
@@ -222,12 +246,12 @@ namespace Codeine
 //                 << entryHelper( plate, i18n("Genre"), meta( XINE_META_INFO_GENRE ) )
 //                 << entryHelper( plate, i18n("Album"), meta( XINE_META_INFO_ALBUM ) )
 //                 << entryHelper( plate, i18n("Year"), meta( XINE_META_INFO_YEAR ) ) );
-// 
+//
 //         s += sectionHelper( i18n("Audio Properties"),
 //             QStringList()
 //                 << entryHelper( plate, i18n("Bitrate"), info( i18n("%1 bps"), XINE_STREAM_INFO_AUDIO_BITRATE ) )
 //                 << entryHelper( plate, i18n("Sample-rate"), info( i18n("%1 Hz"),  XINE_STREAM_INFO_AUDIO_SAMPLERATE ) ) );
-// 
+//
 //         s += sectionHelper( i18n("Technical Information"),
 //             QStringList()
 //                 << entryHelper( plate, i18n("Video Codec"), meta( XINE_META_INFO_VIDEOCODEC ) )
@@ -235,18 +259,18 @@ namespace Codeine
 //                 << entryHelper( plate, i18n("System Layer"), meta( XINE_META_INFO_SYSTEMLAYER ) )
 //                 << entryHelper( plate, i18n("Input Plugin"), meta( XINE_META_INFO_INPUT_PLUGIN  ))
 //                 << entryHelper( plate, i18n("CDINDEX_DISCID"), meta( XINE_META_INFO_CDINDEX_DISCID ) ) );
-// 
+//
 //         QStringList texts;
 //         texts << "BITRATE" << "SEEKABLE" << "VIDEO_WIDTH" << "VIDEO_HEIGHT" << "VIDEO_RATIO" << "VIDEO_CHANNELS" << "VIDEO_STREAMS" << "VIDEO_BITRATE" << "VIDEO_FOURCC" << "VIDEO_HANDLED" << "FRAME_DURATION" << "AUDIO_CHANNELS" << "AUDIO_BITS" << "-AUDIO_SAMPLERATE" << "-AUDIO_BITRATE" << "AUDIO_FOURCC" << "AUDIO_HANDLED" << "HAS_CHAPTERS" << "HAS_VIDEO" << "HAS_AUDIO" << "-IGNORE_VIDEO" << "-IGNORE_AUDIO" << "-IGNORE_SPU" << "VIDEO_HAS_STILL" << "MAX_AUDIO_CHANNEL" << "MAX_SPU_CHANNEL" << "AUDIO_MODE" << "SKIPPED_FRAMES" << "DISCARDED_FRAMES";
-// 
+//
 //         s += "<h2>Other</h2>";
 //         for( uint x = 0; x <= 28; ++x )
 //             s += entryHelper( plate, texts[x], simple( x ) );
-// 
+//
 //         #undef meta
 //         #undef info
 //         #undef simple
-// 
+//
 //         return s;
     }
 */
