@@ -31,6 +31,7 @@
 #include <kwindowsystem.h>
 
 #include <QTimer>
+#include <QWheelEvent>
 #include <QColor>
 #include <QPushButton>
 #include <QPalette>
@@ -61,9 +62,11 @@ PassiveInfo::PassiveInfo(SystemTray *parent) :
     connect(m_timer, SIGNAL(timeout()), SLOT(timerExpired()));
     setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
 
-    // I'd like StyledPanel but it doesn't work in the default KDE style...
-    setFrameStyle(Box | Plain);
-    setLineWidth(3);
+    // Workaround transparent background in Oxygen when (ab-)using Qt::ToolTip
+    setAutoFillBackground(true);
+
+    setFrameStyle(StyledPanel | Plain);
+    setLineWidth(2);
 }
 
 void PassiveInfo::startTimer(int delay)
@@ -117,6 +120,18 @@ void PassiveInfo::hideEvent(QHideEvent *)
 {
 }
 
+void PassiveInfo::wheelEvent(QWheelEvent *e)
+{
+    if(e->delta() >= 0) {
+        emit nextSong();
+    }
+    else {
+        emit previousSong();
+    }
+
+    e->accept();
+}
+
 void PassiveInfo::positionSelf()
 {
     // Start with a QRect of our size, move it to the right spot.
@@ -187,7 +202,7 @@ SystemTray::SystemTray(PlayerManager *player, QWidget *parent) :
     cm->addAction( action("togglePopups") );
 
     m_fadeTimer = new QTimer(this);
-    m_fadeTimer->setObjectName("systrayFadeTimer");
+    m_fadeTimer->setObjectName( QLatin1String("systrayFadeTimer" ));
     connect(m_fadeTimer, SIGNAL(timeout()), SLOT(slotNextStep()));
 
     // Handle wheel events
@@ -364,6 +379,8 @@ void SystemTray::createPopup()
     m_popup = new PassiveInfo(this);
     connect(m_popup, SIGNAL(destroyed()), SLOT(slotPopupDestroyed()));
     connect(m_popup, SIGNAL(timeExpired()), SLOT(slotFadeOut()));
+    connect(m_popup, SIGNAL(nextSong()), SLOT(slotForward()));
+    connect(m_popup, SIGNAL(previousSong()), SLOT(slotBack()));
 
     KHBox *box = new KHBox(m_popup);
     box->setSpacing(15); // Add space between text and buttons
@@ -407,11 +424,11 @@ void SystemTray::createButtonBox(QWidget *parent)
     buttonBox->setSpacing(3);
 
     QPushButton *forwardButton = new QPushButton(m_forwardPix, 0, buttonBox);
-    forwardButton->setObjectName("popup_forward");
+    forwardButton->setObjectName( QLatin1String("popup_forward" ));
     connect(forwardButton, SIGNAL(clicked()), SLOT(slotForward()));
 
     QPushButton *backButton = new QPushButton(m_backPix, 0, buttonBox);
-    backButton->setObjectName("popup_back");
+    backButton->setObjectName( QLatin1String("popup_back" ));
     connect(backButton, SIGNAL(clicked()), SLOT(slotBack()));
 }
 
