@@ -1,4 +1,4 @@
-/*
+/* vim: noexpandtab
  * Kscd - A simple cd player for the KDE Project
  *
  * Copyright (c) 1997 Bernd Johannes wuebben@math.cornell.edu
@@ -69,7 +69,7 @@ KSCD::KSCD( QWidget *parent ) : KscdWindow(parent)
 
 	/** Music Brainz initialisation	*/
 	m_MBManager = new MBManager();
-	m_MBManager->discLookup();
+	m_MBManager->discLookup(devices->getMedia()->currentSource().deviceName());
 
 	setupActions();
 	setupContextMenu();
@@ -105,7 +105,7 @@ void KSCD::setupActions()
 	m_downloadAction = m_actions->addAction(i18n("Download Info"));
 	m_downloadAction->setText(i18n("Download Info"));
 	addAction(m_downloadAction);
-	connect(m_downloadAction, SIGNAL(triggered()), m_MBManager, SLOT(discLookup()));
+	connect(m_downloadAction, SIGNAL(triggered()), this, SLOT(discLookup()));
 
 	//upload info
 	m_uploadAction = m_actions->addAction( QLatin1String( "Upload Info" ));
@@ -235,11 +235,16 @@ void KSCD::setupActions()
 	connect(m_MBManager, SIGNAL(showTrackinfoLabel(QString&)), this, SLOT(showTrackinfoLabel(QString&)));
 
 	connect(devices,SIGNAL(trackChanged()),this,SLOT(restoreTrackinfoLabel()));
-	connect(devices,SIGNAL(cdLoaded()),m_MBManager,SLOT(discLookup()));
+	connect(devices,SIGNAL(cdLoaded(const QString&)),m_MBManager,SLOT(discLookup(const QString&)));
 
 	connect( this , SIGNAL( customContextMenuRequested( const QPoint &) ) , SLOT( showContextMenu( const QPoint &) ) );
 }
 
+void KSCD::discLookup()
+{
+	m_MBManager->discLookup(devices->getMedia()->currentSource().deviceName());
+}
+
 void KSCD::setupContextMenu()
 {
 	contextMenu = new QMenu( this );
@@ -286,9 +291,13 @@ void KSCD::restoreTrackinfoLabel()
 	if (devices->getCD()->isCdInserted()  && currentTrack > 0 )
 	{
 
-            title = QString::fromLatin1("%1 - ").arg(currentTrack, 2, 10, QLatin1Char('0')) ;
-		title.append(m_MBManager->getTrackList()[currentTrack-1].Title);
-		length.append(m_MBManager->getTrackList()[currentTrack-1].Duration);
+		title = QString::fromLatin1("%1 - ").arg(currentTrack, 2, 10, QLatin1Char('0')) ;
+
+		if (m_MBManager->getTrackList().size() >= (currentTrack))
+		{
+			title.append(m_MBManager->getTrackList()[currentTrack-1].Title);
+			length.append(m_MBManager->getTrackList()[currentTrack-1].Duration);
+		}
 
 		showTrackinfoLabel(title);
 		m_popup = new TitlePopUp(this, QLatin1String( "popup" ));
